#ifndef SELECT_SINGLE_CONTENT_ITEM_PAGE_H
#define SELECT_SINGLE_CONTENT_ITEM_PAGE_H

#include <MApplicationPage>

class ContentItemsPagePrivate;

/**
 * @class SelectSingleContentItemPage
 * @ingroup PublicAPI
 * @credential relevance::RelevanceAllContentTypes Needed for finding results
 * @credential smartsearch::RelevanceAllContentTypes Needed for finding results
 * @brief Page used to show the the content list and support searching and picking one item.
 *
 * This application page can be used when an application needs to select one single content
 * item. Typical use of this class is:
 *
 * @code
 * SelectSingleContentItemPage* page = new SelectSingleContentItemPage("", QStringList(), "" );
 * page->setTitle("My Picker");
 *
 * connect(page, SIGNAL(contentItemSelected( const QString & )),
 *         this, SLOT(contentItemSelected( const QString & )));
 *
 * // make sure the current page is shown when the search page is done
 * connect(page, SIGNAL(backButtonClicked()), myCurrentPage, SLOT(appear()));
 *
 * page->appear(myWindow, MSceneWindow::DestroyWhenDismissed );
 * @endcode
 *
 * @section searchQuery Specifying a default search query
 * This is a single text string that will be used to perform an initial search. It will be shown in a text edit at in the page and works
 * just as if the user had entered it manually. When the page has been shown the user can change this string and new searches will be
 * performed.

 * @section preselectedFilters Specifying content types and filters
 * This is a list of URIs of content types. Content type filters can be string like:
 *
 * @li "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#PersonContact"
 * @li "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#Media"
 *
 * @section preselectedItems Specifying a default selection
 * This is a list of URIs to items that should be selected by default in the picker. This can be for instance a previous selected item or
 * something that just should be selected.
 *
 * The constructor can be given various parameters to fine tune what can be searched and what should be already preselected when the picker starts. 
 *
 * Results are emitted through a signal: contentItemSelected,  when user taps on item.
 *
 * When user click the back button, just emit backButtonClicked signal,which inherit from MApplicationPage.
 **/
class SelectSingleContentItemPage : public MApplicationPage {

    Q_OBJECT
    
public:
    
    /**
     * Creates the page. The @p text_query is a search string that should be "presearched" and it will be saved in the
     * search field which is shown at the top of the screen. The @p preselected_filters is a list of various filters that
     * should be used to narrow down the available content. These filters can be:
     *
     * @li tag uris
     * @li content type uris
     * @li date range uris (needs specification!)
     *
     * The @p preselected_item is an uri to an item that should be preselected in the result list (assuming it is actually
     * found). This can be for instance some previous selection that should be default if the user just presses @e back
     * without selecting anything.
     *
     * @param text_query the optional free text query used to perform the initial search.
     * @param preselected_filters an optional list of filters used to narrow down content.
     * @param preselected_item the uri to an optional item that should be preselected.
     * @param parent optional parent item.
     **/
    SelectSingleContentItemPage (const QString &text_query="", const QStringList &preselected_filters=QStringList(), const QString &preselected_item="",
                                 QGraphicsItem *parent=0);

    /**
     * \brief Destructor
     **/
    ~SelectSingleContentItemPage();


Q_SIGNALS:

    /**
     * Signal emitted when the user clicks the @e done button. The @p content_item will contain the uri of the selected
     * item. If nothing was selected then the string will be empty.
     * will be closed.
     *
     * @param content_item uri of the selected item or an empty string if nothing was selected.
     **/
    void contentItemSelected( const QString &content_item );

private:

    //! private implementation and data
    ContentItemsPagePrivate* m_dptr;

    Q_DISABLE_COPY(SelectSingleContentItemPage)
};

#endif // SELECT_SINGLE_CONTENT_ITEM_PAGE_H
